==> scorchful-0.15.8%2B1.21.1-sources.jar: com/github/thedeathlycow/scorchful/compat/DehydrationServerThirstPlugin.java <==
package com.github.thedeathlycow.scorchful.compat;

import com.github.thedeathlycow.scorchful.Scorchful;
import com.github.thedeathlycow.scorchful.api.ServerThirstPlugin;
import com.github.thedeathlycow.scorchful.config.DehydrationConfig;
import net.dehydration.access.ThirstManagerAccess;
import net.dehydration.thirst.ThirstManager;
import net.minecraft.class_1657;
import net.minecraft.class_3532;

public class DehydrationServerThirstPlugin implements ServerThirstPlugin {
    @Override
    public boolean dehydrateFromSweating(class_1657 player) {
        DehydrationConfig config = Scorchful.getConfig().integrationConfig.dehydrationConfig;
        ThirstManager thirstManager = ((ThirstManagerAccess) player).getThirstManager();
        if (thirstManager.getThirstLevel() > config.getMinWaterLevelForSweat()
                && player.thermoo$getTemperature() > 0) {
            thirstManager.addDehydration(config.getDehydrationConsumedBySweat());
            return true;
        }

        return false;
    }

    @Override
    public void rehydrateFromEnchantment(class_1657 player, int waterCaptured, double rehydrationEfficiency) {
        ThirstManager thirstManager = ((ThirstManagerAccess) player).getThirstManager();

        DehydrationConfig dehydrationConfig = Scorchful.getConfig().integrationConfig.dehydrationConfig;
        // dont drink if dont have to - prevents rehydration spam
        if (thirstManager.getThirstLevel() > dehydrationConfig.getMinWaterLevelForSweat()) {
            return;
        }

        int maxWater = class_3532.method_15357(rehydrationEfficiency * dehydrationConfig.getMaxWaterLost());
        int waterToAdd = player.method_59922().method_39332(1, maxWater);
        thirstManager.add(waterToAdd);
    }

    @Override
    public int getRehydrationThreshold() {
        return Scorchful.getConfig().integrationConfig.dehydrationConfig.getRehydrationDrinkSize();
    }
}

==> scorchful-0.16.0%2B1.21.9-sources.jar: com/github/thedeathlycow/scorchful/compat/DehydrationServerThirstPlugin.java <==
package com.github.thedeathlycow.scorchful.compat;

import com.github.thedeathlycow.scorchful.api.ServerThirstPlugin;
import com.github.thedeathlycow.scorchful.config.ScorchfulConfig;
import com.github.thedeathlycow.scorchful.config.section.DehydrationConfig;
import net.dehydration.access.ThirstManagerAccess;
import net.dehydration.thirst.ThirstManager;
import net.minecraft.class_1657;
import net.minecraft.class_3532;

public class DehydrationServerThirstPlugin implements ServerThirstPlugin {
    @Override
    public boolean dehydrateFromSweating(class_1657 player) {
        DehydrationConfig config = ScorchfulConfig.getDehydrationConfig();
        ThirstManager thirstManager = ((ThirstManagerAccess) player).getThirstManager();
        if (thirstManager.getThirstLevel() > config.getMinWaterLevelForSweat()
                && player.thermoo$getTemperature() > 0) {
            thirstManager.addDehydration(config.getDehydrationConsumedBySweat());
            return true;
        }

        return false;
    }

    @Override
    public void rehydrateFromEnchantment(class_1657 player, int waterCaptured, double rehydrationEfficiency) {
        ThirstManager thirstManager = ((ThirstManagerAccess) player).getThirstManager();

        DehydrationConfig dehydrationConfig = ScorchfulConfig.getDehydrationConfig();
        // dont drink if dont have to - prevents rehydration spam
        if (thirstManager.getThirstLevel() > dehydrationConfig.getMinWaterLevelForSweat()) {
            return;
        }

        int maxWater = class_3532.method_15357(rehydrationEfficiency * dehydrationConfig.getMaxWaterLost());
        int waterToAdd = player.method_59922().method_39332(1, maxWater);
        thirstManager.add(waterToAdd);
    }

    @Override
    public int getRehydrationThreshold() {
        return ScorchfulConfig.getDehydrationConfig().getRehydrationDrinkSize();
    }
}
